(landmark-examples)=

# Landmark-based morphometrics examples

Examples concerning the :mod:`ktch.landmark` module.

```{eval-rst}
.. toctree::
    :maxdepth: 1
    :glob:

    ./generalized_Procrustes_analysis
    ./gpa_from_tps
    ./thin_plate_spline
```